#include "../../bundle/basil.js";
// Version for basil.js v.1.1.0
// Golan Levin, November 2018

//--------------------------------------------------------
function setup() {
 
  // Load a JSON file containing your book's content. This is expected
  // to be located in the "data" folder adjacent to your .indd and .jsx. 
  var jsonString = b.loadString("myPoems.json");

  // Clear the document at the very start. 
  b.clear (b.doc());

  // Parse the JSON file into the jsonData array
  var jsonData = b.JSON.decode( jsonString );
  var poems = jsonData.poems; 
  b.println("Number of poems: " + poems.length);

  // Initialize some variables for element placement positions.
  // Remember that the units are "points", 72 points = 1 inch.
  var inch = 72;

  var titleW = inch * 5.0;
  var titleH = inch * 0.5;
  var titleX = (b.width / 2) - (titleW / 2); // centered 
  var titleY = inch * 1.0;

  var textX = inch * 1.0; 
  var textY = inch * 2.5;
  var textW = inch * 4.0;
  var textH = inch * 5.0;

  // Loop over every element of the book content array
  // (Here assumed to be separate pages)
  for (var i = 0; i < poems.length; i++) {

    //----------------------------
    // Format and display the "title" field.
    b.noStroke(); 
    b.fill(0,0,0);
    b.textSize(30);
    b.textFont("Helvetica","Bold"); 
    b.textAlign(Justification.CENTER_ALIGN, VerticalJustification.CENTER_ALIGN );
    b.text(poems[i].title, titleX,titleY,titleW,titleH);

    //----------------------------
    // Format and display the poem's "text" field. 
    // This time, let's do some typographic tricks.
    b.textFont("Times New Roman","Regular"); 
    b.textAlign(Justification.LEFT_ALIGN, VerticalJustification.TOP_ALIGN );
    
    // Get the text of the i'th poem
    var poemText = poems[i].text;
    
    // Create an InDesign TextFrame from this text
    var thePoemTextFrame = b.text(poemText, textX,textY,textW,textH);
    
    // Fetch the individual words in this TextFrame; 
    // Underline the first (0'th) word. 
    var poemWords = b.words (thePoemTextFrame);
    b.typo(poemWords[0],'underline', true);

    // Give each word its own (random) grayscale color.
    var poemLines = b.lines (thePoemTextFrame);
    for (var w=0; w<poemWords.length; w++){
      var wthWord = poemWords[w];
      var wordR = b.random(0, 180); 
      var wordG = b.random(0, 180); 
      var wordB = b.random(0, 180); 
      b.typo(wthWord,'fillColor', b.color(wordR, wordG, wordB));
    }

    // Fetch the individual characters in this TextFrame; 
    // Give each character its own type size, gradually
    // shrinking the characters as we go. 
    var poemChars = b.characters (thePoemTextFrame);
    var nPoemChars = poemChars.length; 
    for (var c=0; c<nPoemChars; c++){
      var cthChar = poemChars[c];
      var charSize = b.map(c, 0, nPoemChars, 40, 18); 
      b.typo(cthChar, "pointSize", charSize); 
    }

    //----------------------------
    // Create the next page. 
    if (i < (poems.length-1)){
      b.addPage();
    }
  }

  // Ensure that there are an even 
  // number of pages in the document. 
  if ((poems.length % 2) > 0){
    b.addPage();
  }
}


// This makes it all happen:
b.go(); 
